@@ -65,14 +65,13 @@ class Wrapper:
         request.write_stream    = stream_name
 
         try:
-            logging.basicConfig(level=logging.DEBUG)
             response_future_1 = append_rows_stream.send(request)
-            logging.basicConfig(level=logging.DEBUG)
         except Exception as e:
             print("ERROR:" + str(e))
             return None
 
-        append_rows_stream.close()
+        while not append_rows_stream.is_active:
+            append_rows_stream.close()
 
         bq_storage_client.finalize_write_stream(name=stream_name)
 
