@@ -3,6 +3,8 @@
 #   Created on 5/4/2022
 #
 
+import datetime
+import uuid
 from indxdatalaketools import Helpers
 
 class Wrapper:
@@ -60,7 +62,7 @@ class Wrapper:
         if 'gs://' in file_path:
             bucket_name         = file_path.replace("gs://", '').split('/')[0]
             gcs_file_path       = file_path.replace("gs://"+bucket_name+"/",'')
-            blob_name           = prefix + "/" + mrn + "_" + file_path.split('/')[-1]
+            blob_name           = prefix + "/" + mrn + "_" + str(uuid.uuid4()) + "_" + file_path.split('/')[-1]
             source_bucket       = self.__google_cloud_storage_client.bucket(bucket_name)
             destination_bucket  = self.__google_cloud_storage_client.bucket(client_uuid)
             blob                = source_bucket.blob(gcs_file_path)
@@ -72,7 +74,7 @@ class Wrapper:
         else:
             file_path           = file_path.replace("\\", "/")
             file_name           = file_path.split("/")[-1]
-            blob_name           = prefix + "/" + mrn + "_" + file_name
+            blob_name           = prefix + "/" + mrn + "_" + str(uuid.uuid4()) + "_" + file_name
             bucket              = self.__google_cloud_storage_client.bucket(client_uuid)
             blob                = bucket.blob(blob_name)
             upload_result       = self.__upload_blob_from_local(blob, file_path)
